import request from "@/utils/request";

// 服务列表
export function serviceList(params) {
  return request({
    url: "/business/solution/list",
    method: "get",
    params,
  });
}
// 服务列表-添加
export function serviceAdd(data) {
  return request({
    url: "/business/solution",
    method: "post",
    data,
  });
}
// 服务列表-修改
export function serviceEdit(data) {
  return request({
    url: "/business/solution",
    method: "put",
    data,
  });
}
// 服务列表-删除
export function serviceDelete(ids) {
  return request({
    url: `/business/solution/${ids}`,
    method: "delete",
  });
}
// 服务类型-select
export function serviceCaseKindSelect() {
  return request({
    url: "/business/solution/getAllCategory",
    method: "get",
  });
}

// 服务案例列表
export function serviceCaseList(params) {
  return request({
    url: "/business/solutionCase/list",
    method: "get",
    params,
  });
}
// 服务案例-添加
export function serviceCaseAdd(data) {
  return request({
    url: "/business/solutionCase",
    method: "post",
    data,
  });
}
// 服务案例-详情
export function serviceCaseDetail(id) {
  return request({
    url: `/business/solutionCase/${id}`,
    method: "get",
  });
}
// 服务案例-修改
export function serviceCaseEdit(data) {
  return request({
    url: "/business/solutionCase",
    method: "put",
    data,
  });
}
// 服务案例-删除
export function serviceCaseDelete(ids) {
  return request({
    url: `/business/solutionCase/${ids}`,
    method: "delete",
  });
}

// 解决方案导航列表
export function planCategoryList(params) {
  return request({
    url: `/business/planCategory/list`,
    method: "get",
    params,
  });
}

// 解决方案导航新增
export function planCategoryAdd(data) {
  return request({
    url: `/business/planCategory`,
    method: "post",
    data,
  });
}
// 解决方案导航删除
export function planCategoryDelete(ids) {
  return request({
    url: `/business/planCategory`,
    method: "delete",
    data: {
      ids,
    },
  });
}
// 解决方案导航详情
export function planCategoryDetail(id) {
  return request({
    url: `/business/planCategory/${id}`,
    method: "get",
  });
}
// 解决方案导航修改
export function planCategoryUpdate(data) {
  return request({
    url: `/business/planCategory`,
    method: "put",
    data,
  });
}
